@@ -5,8 +5,8 @@
 */
 
 #include "lineeditwithautocorrectiontest.h"
-#include "../autocorrection.h"
 #include <PimCommon/LineEditWithAutoCorrection>
+#include <PimCommonAutoCorrection/AutoCorrection>
 #include <QTest>
 #include <qtestkeyboard.h>
 
@@ -19,7 +19,9 @@ void LineEditWithAutocorrectionTest::shouldNotAutocorrectWhenDisabled()
     const QString originalWord = QStringLiteral("FOOFOO");
     const QString replaceWord = QStringLiteral("BLABLA");
     entries.insert(originalWord, replaceWord);
-    lineedit.autocorrection()->setAutocorrectEntries(entries);
+    auto settings = new PimCommonAutoCorrection::AutoCorrectionSettings;
+    settings->setAutocorrectEntries(entries);
+    lineedit.autocorrection()->setAutoCorrectionSettings(settings);
     lineedit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&lineedit));
     QTest::keyClicks(&lineedit, originalWord);
@@ -34,9 +36,11 @@ void LineEditWithAutocorrectionTest::shouldReplaceWordWhenExactText()
     const QString replaceWord = QStringLiteral("BLABLA");
     QHash<QString, QString> entries;
     entries.insert(originalWord, replaceWord);
-    lineedit.autocorrection()->setAutocorrectEntries(entries);
-    lineedit.autocorrection()->setEnabledAutoCorrection(true);
-    lineedit.autocorrection()->setAdvancedAutocorrect(true);
+    auto settings = new PimCommonAutoCorrection::AutoCorrectionSettings;
+    settings->setAutocorrectEntries(entries);
+    settings->setEnabledAutoCorrection(true);
+    settings->setAdvancedAutocorrect(true);
+    lineedit.autocorrection()->setAutoCorrectionSettings(settings);
     lineedit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&lineedit));
     QTest::keyClicks(&lineedit, originalWord);
@@ -51,9 +55,11 @@ void LineEditWithAutocorrectionTest::shouldNotReplaceWordWhenInexactText()
     const QString replaceWord = QStringLiteral("BLABLA");
     QHash<QString, QString> entries;
     entries.insert(originalWord, replaceWord);
-    lineedit.autocorrection()->setAutocorrectEntries(entries);
-    lineedit.autocorrection()->setEnabledAutoCorrection(true);
-    lineedit.autocorrection()->setAdvancedAutocorrect(true);
+    auto settings = new PimCommonAutoCorrection::AutoCorrectionSettings;
+    settings->setAutocorrectEntries(entries);
+    settings->setEnabledAutoCorrection(true);
+    settings->setAdvancedAutocorrect(true);
+    lineedit.autocorrection()->setAutoCorrectionSettings(settings);
     lineedit.show();
     const QString nonExactText = QStringLiteral("BLIBLI");
     QVERIFY(QTest::qWaitForWindowExposed(&lineedit));
@@ -66,8 +72,10 @@ void LineEditWithAutocorrectionTest::shouldNotAddTwoSpace()
 {
     PimCommon::LineEditWithAutoCorrection lineedit(nullptr, QStringLiteral("lineeditwithautocorrecttestrc"));
     const QString originalWord = QStringLiteral("FOOFOO ");
-    lineedit.autocorrection()->setSingleSpaces(true);
-    lineedit.autocorrection()->setEnabledAutoCorrection(true);
+    auto settings = new PimCommonAutoCorrection::AutoCorrectionSettings;
+    settings->setSingleSpaces(true);
+    settings->setEnabledAutoCorrection(true);
+    lineedit.autocorrection()->setAutoCorrectionSettings(settings);
     lineedit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&lineedit));
     QTest::keyClicks(&lineedit, originalWord);
