@@ -9,10 +9,13 @@
 #include "pimcommon_export.h"
 
 #include <PimCommon/SpellCheckLineEdit>
+namespace PimCommonAutoCorrection
+{
+class AutoCorrection;
+}
 
 namespace PimCommon
 {
-class AutoCorrection;
 class LineEditWithAutoCorrectionPrivate;
 /**
  * @brief The LineEditWithAutoCorrection class
@@ -25,9 +28,9 @@ public:
     explicit LineEditWithAutoCorrection(QWidget *parent, const QString &configFile);
     ~LineEditWithAutoCorrection() override;
 
-    Q_REQUIRED_RESULT PimCommon::AutoCorrection *autocorrection() const;
+    Q_REQUIRED_RESULT PimCommonAutoCorrection::AutoCorrection *autocorrection() const;
 
-    void setAutocorrection(PimCommon::AutoCorrection *autocorrect);
+    void setAutocorrection(PimCommonAutoCorrection::AutoCorrection *autocorrect);
     void setAutocorrectionLanguage(const QString &language);
 
 protected:
