@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,9 +26,7 @@ public:
     class GenericPluginData
     {
     public:
-        GenericPluginData()
-        {
-        }
+        GenericPluginData() = default;
 
         QString mDescription;
         QString mName;
@@ -56,7 +54,6 @@ public:
     Q_REQUIRED_RESULT GenericPlugin *pluginFromIdentifier(const QString &id);
 
 private:
-    GenericPluginManagerPrivate *const d;
+    std::unique_ptr<GenericPluginManagerPrivate> const d;
 };
 }
-
