@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef BLACKLISTBALOOEMAILWARNING_H
-#define BLACKLISTBALOOEMAILWARNING_H
+#pragma once
 
 #include "pimcommonakonadi_private_export.h"
 #include <KMessageWidget>
@@ -29,4 +28,3 @@ private:
     void slotSearch();
 };
 }
-#endif // BLACKLISTBALOOEMAILWARNING_H
