@@ -15,7 +15,6 @@
 #include <KLDAP/LdapSearchClientReadConfigServerJob>
 #include <Libkdepim/LineEditCatchReturnKey>
 #include <Libkdepim/ProgressIndicatorLabel>
-#include <kcontacts_version.h>
 
 #include <QApplication>
 #include <QCheckBox>
@@ -28,6 +27,7 @@
 #include <QLabel>
 #include <QMenu>
 #include <QPair>
+#include <QPointer>
 #include <QPushButton>
 #include <QSortFilterProxyModel>
 #include <QTableView>
@@ -54,7 +54,7 @@ using namespace PimCommon;
 static QString asUtf8(const QByteArray &val)
 {
     if (val.isEmpty()) {
-        return QString();
+        return {};
     }
 
     const char *data = val.data();
@@ -162,13 +162,9 @@ static KContacts::Addressee convertLdapAttributesToAddressee(const KLDAP::LdapAt
     KLDAP::LdapAttrValue::ConstIterator it = lst.constBegin();
     bool pref = true;
     while (it != lst.constEnd()) {
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
-        addr.insertEmail(asUtf8(*it), pref);
-#else
         KContacts::Email email(asUtf8(*it));
         email.setPreferred(pref);
         addr.addEmail(email);
-#endif
         pref = false;
         ++it;
     }
@@ -243,7 +239,7 @@ public:
         endResetModel();
     }
 
-    QPair<KLDAP::LdapAttrMap, QString> contact(const QModelIndex &index) const
+    Q_REQUIRED_RESULT QPair<KLDAP::LdapAttrMap, QString> contact(const QModelIndex &index) const
     {
         if (!index.isValid() || index.row() < 0 || index.row() >= mContactList.count()) {
             return qMakePair(KLDAP::LdapAttrMap(), QString());
@@ -252,19 +248,19 @@ public:
         return qMakePair(mContactList.at(index.row()), mServerList.at(index.row()));
     }
 
-    QString email(const QModelIndex &index) const
+    Q_REQUIRED_RESULT QString email(const QModelIndex &index) const
     {
         if (!index.isValid() || index.row() < 0 || index.row() >= mContactList.count()) {
-            return QString();
+            return {};
         }
 
         return asUtf8(mContactList.at(index.row()).value(QStringLiteral("mail")).first()).trimmed();
     }
 
-    QString fullName(const QModelIndex &index) const
+    Q_REQUIRED_RESULT QString fullName(const QModelIndex &index) const
     {
         if (!index.isValid() || index.row() < 0 || index.row() >= mContactList.count()) {
-            return QString();
+            return {};
         }
 
         return asUtf8(mContactList.at(index.row()).value(QStringLiteral("cn")).first()).trimmed();
@@ -278,7 +274,7 @@ public:
         endResetModel();
     }
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const override
+    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (!parent.isValid()) {
             return mContactList.count();
@@ -287,7 +283,7 @@ public:
         }
     }
 
-    int columnCount(const QModelIndex &parent = QModelIndex()) const override
+    Q_REQUIRED_RESULT int columnCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (!parent.isValid()) {
             return 18;
@@ -296,10 +292,10 @@ public:
         }
     }
 
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
+    Q_REQUIRED_RESULT QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
     {
         if (orientation == Qt::Vertical || role != Qt::DisplayRole || section < 0 || section > 17) {
-            return QVariant();
+            return {};
         }
 
         switch (section) {
@@ -340,18 +336,18 @@ public:
         case 17:
             return i18nc("@title:column Column containing title of the person", "Title");
         default:
-            return QVariant();
+            return {};
         }
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
+    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (!index.isValid()) {
-            return QVariant();
+            return {};
         }
 
         if (index.row() < 0 || index.row() >= mContactList.count() || index.column() < 0 || index.column() > 17) {
-            return QVariant();
+            return {};
         }
 
         if (role == ServerRole) {
@@ -359,7 +355,7 @@ public:
         }
 
         if ((role != Qt::DisplayRole) && (role != Qt::ToolTipRole)) {
-            return QVariant();
+            return {};
         }
 
         const KLDAP::LdapAttrMap map = mContactList.at(index.row());
@@ -402,7 +398,7 @@ public:
         case 17:
             return join(map.value(QStringLiteral("title")), QStringLiteral(", "));
         default:
-            return QVariant();
+            return {};
         }
     }
 
